@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -17,7 +17,7 @@ void BlackListBalooEmailUtil::initialBlackList(const QStringList &blackList)
     mInitialList = blackList;
 }
 
-void BlackListBalooEmailUtil::newBlackList(const QHash<QString, bool> &list)
+void BlackListBalooEmailUtil::setNewBlackList(const QHash<QString, bool> &list)
 {
     mNewBlackList = list;
 }
